@@ -4,7 +4,7 @@ use base 'Aspect::JoinPoint';
 use Class::MethodMaker
     get_set => 'sub';
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 sub init {
 	my $self = shift;
@@ -83,11 +83,11 @@ author.
 
 =head1 AUTHOR
 
-Marcel Grunauer, <marcel@codewerk.com>
+Marcel GrE<uuml>nauer <marcel.gruenauer@chello.at>
 
 =head1 COPYRIGHT
 
-Copyright 2001 Marcel Grunauer. All rights reserved.
+Copyright 2001 Marcel GrE<uuml>nauer. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
