@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use base 'Aspect::PointCut::Sub';
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 sub join_point_type { 'Aspect::JoinPoint::Call' }
 
@@ -65,11 +65,11 @@ author.
 
 =head1 AUTHOR
 
-Marcel Grunauer, <marcel@codewerk.com>
+Marcel GrE<uuml>nauer <marcel.gruenauer@chello.at>
 
 =head1 COPYRIGHT
 
-Copyright 2001 Marcel Grunauer. All rights reserved.
+Copyright 2001 Marcel GrE<uuml>nauer. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
